@@ -49,6 +49,7 @@ class MLEnv():
         self.gpu_memory = None  #: GPU memory for NVidia cards as provided by `nvidia-smi`
         self.is_notebook = False  #: `True` if running in a notebook
         self.is_colab = False  #: `True` if running in a colab notebook
+        self.tpu_strategy = None
         if platform == 'tf':
             try:
                 import tensorflow as tf
@@ -64,7 +65,7 @@ class MLEnv():
                 self.tf_prof = False
             self.log.debug(f"Tensorflow version: {tf.__version__}")
             if accelerator == 'tpu' or accelerator == 'fastest':
-                try:
+                try:  # XXX This fails in non-eager mode! Switch back?
                     tpu = tf.distribute.cluster_resolver.TPUClusterResolver()  # TPU detection
                     tpc=tpu.cluster_spec().as_dict()['worker']
                     self.log.debug(f'Running on TPU {tpc}')
@@ -88,6 +89,8 @@ class MLEnv():
                             self.log.info("You got old TPU v2 which is limited to 8GB Ram.")
                     self.tpu_type = tpu_type
                     self.log.debug("TPU strategy available")
+                    tf.compat.v1.disable_eager_execution()
+                    self.log.debug("TPU: eager execution disabled!")
             if self.is_tpu is False:
                 if accelerator == 'gpu' or accelerator == 'fastest':
                     try:
